@@ -61,7 +61,8 @@ class Consumer:
             msg = body.decode()
             logging.debug("[Consumer] Message received: " + str(msg))
         except Exception("Error with msg from RabbitMQ") as e:
-            logging.error(f"[Consumer] Failed with msg from RabbitMQ {str(msg)}")
+            logging.error(
+                f"[Consumer] Failed with msg from RabbitMQ {str(msg)}")
             raise e
         try:
             msg = json.loads(msg)
@@ -70,13 +71,16 @@ class Consumer:
             raise e
         if 'message_type' not in msg:
             raise Exception("message_type not in msg from RBMQ")
-        logging.debug(f"[Consumer] Message type ready {type(msg['message_type'])}")
+        logging.debug(
+            f"[Consumer] Message type ready {type(msg['message_type'])}")
         if msg['message_type'] == RBMQ_aggregation_status:
-            logging.debug("[Consumer] Putting agg_id to Queue: " + str(msg['body']['aggregation_id']))
+            logging.debug("[Consumer] Putting agg_id to Queue: " +
+                          str(msg['body']['aggregation_id']))
             self.msg_queue.put(msg['body']['aggregation_id'], block=False)
             ch.basic_ack(delivery_tag=method.delivery_tag)
         elif msg['message_type'] == RBMQ_run_status:
-            logging.debug("[Consumer] setting run_status: " + str(msg['body']['run_status']))
+            logging.debug("[Consumer] setting run_status: " +
+                          str(msg['body']['run_status']))
             self.run_status_callback(msg['body']['run_status'])
         else:
             logging.error(f"Failed to match message type")
@@ -100,6 +104,7 @@ class Consumer:
         return
 
     def spawn_consumer_thread(self):
+        print("Starting Consumer")
         t = ConsumerThread(target=self.start, callback=self.stop, daemon=True)
         t.start()
         return t
