@@ -25,6 +25,8 @@ class Client:
         self.__leaf_id = credentials["leaf_id"]
         self.__leaf_session_token = credentials["leaf_session_token"]
         self.__status = "unauthenticated"
+        self.__tree_id = None
+        self.__branch_id = None
 
         self.__performance_analyser_username = credentials["performance_analyser_username"]
         self.__performance_analyser_password = credentials["performance_analyser_password"]
@@ -197,8 +199,8 @@ class Client:
                                "tree_id": self.__tree_id,
                                "data": data})
 
-            resp = requests.get(url, headers=headers, data=data,
-                                auth=(self.__performance_analyser_username, self.__performance_analyser_password), verify=self.__verify)
+            resp = requests.post(url, headers=headers, data=data,
+                                 auth=(self.__performance_analyser_username, self.__performance_analyser_password), verify=self.__verify)
 
             print(
                 f"received resp code form performance_analyser: {resp.status_code}")
